Crate libfp

Crate libfp 

Re-exports

pub use latch::AnalogLatch;
pub use latch::LatchLayer;
pub use latch::TakeoverMode;

Modules

colors
constants
ext
fp_grids_lib
i2c_proto
latch
quantizer
sysex
Config-over-SysEx v1 wire format shared between firmware and configurator.
types
utils

Structs

ClockConfig
Config
GlobalConfig
GlobalConfig is persisted to FRAM as CBOR. To keep the on-FRAM format forward/backward compatible without writing a migration:
Layout
LayoutIter
MidiCc
MidiChannel
MidiConfig
MidiIn
MidiNote
MidiOut
MidiOutConfig
QuantizerConfig

Enums

AppIcon
AuxJackMode
Persisted in GlobalConfig via CBOR (inside aux: [AuxJackMode; 3]). New variants may be appended with the next free #[n(N)] tag without a migration. Removing a variant requires a one-shot FRAM migration (see storage::migrate_fram).
Brightness
ClockDivision
Persisted in GlobalConfig via CBOR (inside AuxJackMode::ClockOut). New variants may be appended with the next free #[n(N)] tag without a migration. Removing a variant requires a one-shot FRAM migration (see storage::migrate_fram).
ClockSrc
Persisted in GlobalConfig via CBOR. New variants may be appended with the next free #[n(N)] tag without a migration. Removing a variant requires a one-shot FRAM migration (see storage::migrate_fram) — old stored data containing the removed tag would otherwise fail to decode.
Color
ConfigMsgIn
ConfigMsgOut
Curve
I2cMode
Persisted in GlobalConfig via CBOR. New variants may be appended with the next free #[n(N)] tag without a migration. Removing a variant requires a one-shot FRAM migration (see storage::migrate_fram).
Key
Persisted in GlobalConfig via CBOR (inside QuantizerConfig). New variants may be appended with the next free #[n(N)] tag without a migration. Removing a variant requires a one-shot FRAM migration (see storage::migrate_fram).
MidiMode
MidiOutMode
Persisted in GlobalConfig via CBOR (inside MidiOutConfig). New variants may be appended with the next free #[n(N)] tag without a migration. Removing a variant requires a one-shot FRAM migration (see storage::migrate_fram).
Note
Persisted in GlobalConfig via CBOR (inside QuantizerConfig). New variants may be appended with the next free #[n(N)] tag without a migration. Removing a variant requires a one-shot FRAM migration (see storage::migrate_fram).
Param
Range
Supported DAC ranges
ResetSrc
Persisted in GlobalConfig via CBOR. New variants may be appended with the next free #[n(N)] tag without a migration. Removing a variant requires a one-shot FRAM migration (see storage::migrate_fram).
Value
VoltPerOct
Volts-per-octave standard. Selects pitch calibration for quantizer and pitch apps. Standard = 1V/Oct (Eurorack), Buchla = 1.2V/Oct.
Waveform

Constants

APP_MAX_PARAMS
Maximum number of params per app
CALIBRATION_SCALE_FACTOR
CALIBRATION_VERSION_LATEST
CALIB_FILE_MAGIC
GLOBAL_CHANNELS
Total channel size of this device
I2C_ADDRESS
The devices I2C address (as a follower)
I2C_ADDRESS_CALIBRATION
LED_BRIGHTNESS_RANGE
Range in which the LED brightness is scaled
STARTUP_ANIMATION_DURATION
Length of the startup animation

Type Aliases

ConfigMeta
InnerLayout
The config layout is a layout with all the apps in the appropriate spots