Module latch

Module latch 

Structs

AnalogLatch
A stateless machine that implements “catch-up” or “pickup” logic for a fader or knob.

Enums

LatchLayer
TakeoverMode
Defines how a fader should take control of a value when switching layers or starting a session.