Persisted in GlobalConfig via CBOR (inside aux: [AuxJackMode; 3]). New
variants may be appended with the next free #[n(N)] tag without a
migration. Removing a variant requires a one-shot FRAM migration (see
storage::migrate_fram).
Persisted in GlobalConfig via CBOR (inside AuxJackMode::ClockOut). New
variants may be appended with the next free #[n(N)] tag without a
migration. Removing a variant requires a one-shot FRAM migration (see
storage::migrate_fram).
Persisted in GlobalConfig via CBOR. New variants may be appended with the
next free #[n(N)] tag without a migration. Removing a variant
requires a one-shot FRAM migration (see storage::migrate_fram) — old
stored data containing the removed tag would otherwise fail to decode.
Persisted in GlobalConfig via CBOR. New variants may be appended with the
next free #[n(N)] tag without a migration. Removing a variant
requires a one-shot FRAM migration (see storage::migrate_fram).
Persisted in GlobalConfig via CBOR (inside QuantizerConfig). New
variants may be appended with the next free #[n(N)] tag without a
migration. Removing a variant requires a one-shot FRAM migration (see
storage::migrate_fram).
Persisted in GlobalConfig via CBOR (inside MidiOutConfig). New variants
may be appended with the next free #[n(N)] tag without a migration.
Removing a variant requires a one-shot FRAM migration (see
storage::migrate_fram).
Persisted in GlobalConfig via CBOR (inside QuantizerConfig). New
variants may be appended with the next free #[n(N)] tag without a
migration. Removing a variant requires a one-shot FRAM migration (see
storage::migrate_fram).
Persisted in GlobalConfig via CBOR. New variants may be appended with the
next free #[n(N)] tag without a migration. Removing a variant
requires a one-shot FRAM migration (see storage::migrate_fram).